# Maintainers

A repository maintainer is a committer with the additional privilege of merging pull requests into the main branch of this repository.

## Current Maintainers

Maintainers are listed in alphabetical order by last name.

| Name | GitHub Username |
| ---- | ---- |
| Tomas Pilar | [pilartomas](https://github.com/pilartomas) |

For more details on the process of becoming a maintainer, see the [Governance](https://github.com/i-am-bee/community/blob/main/GOVERNANCE.md) document.
